@@ -93,7 +93,7 @@ class Stock:
     def __init__(self, ticker,  target_prices=None, price_invested=None):
         # interval='1m', period='1d',
         try:
-            self.ticker = ticker
+            self.ticker = ticker.upper()
             self.df = Ticker(ticker).get_data()
             self.prev_close = self.df.iloc[-1]
             self.target_prices = target_prices
@@ -298,7 +298,7 @@ class Stock:
   
           # Getting news from google news search
         googlenews = GoogleNews(lang='en', period='14d') # Specify period for news
-        googlenews.get_news(self.ticker + ' stock')
+        googlenews.get_news(f'${self.ticker} stock')
         stock_news = googlenews.results()
   
         # print([(i, j) for i, j in zip(googlenews.get_texts(), googlenews.get_links())])
@@ -311,7 +311,7 @@ class Stock:
         if sectors:
             for sector in sectors:
                 googlenews = GoogleNews(lang='en', period='14d')
-                googlenews.get_news(sector} sector stocks')
+                googlenews.get_news(f'{sector} sector stocks')
                 sector_news.append(googlenews.result())
     
         return df, news, press_releases, sector_news, stock_news
