@@ -34,9 +34,12 @@ class Ticker:
             except:
                 time.sleep(3)
 
-        date = json['Time Series (Daily)']
-        df = pd.DataFrame([[datetime.strptime(date, '%Y-%m-%d'), json[date]['4. close'], json[date]['2. high'], json[date]['3. low'], json[date]['1. open'], json[date]['6. volume']] for date in json.keys()],
+        json = json['Time Series (Daily)']
+        dates = json.keys()
+        
+        df = pd.DataFrame([[datetime.strptime(date, '%Y-%m-%d'), json[date]['4. close'], json[date]['2. high'], json[date]['3. low'], json[date]['1. open'], json[date]['6. volume']] for date in dates],
                           columns=['Date', 'Close', 'High', 'Low', 'Open', 'Volume'])
+        
         df = df.set_index('Date')
 
         return df.iloc[:90]
